@@ -97,6 +97,18 @@ GType ggit_attribute_check_flags_get_type	(void) G_GNUC_CONST;
 #define GGIT_TYPE_PACKBUILDER_STAGE	(ggit_packbuilder_stage_get_type())
 GType ggit_packbuilder_stage_get_type	(void) G_GNUC_CONST;
 
+#define GGIT_TYPE_CHECKOUT_STRATEGY	(ggit_checkout_strategy_get_type())
+GType ggit_checkout_strategy_get_type	(void) G_GNUC_CONST;
+
+#define GGIT_TYPE_CHECKOUT_NOTIFY_FLAGS	(ggit_checkout_notify_flags_get_type())
+GType ggit_checkout_notify_flags_get_type	(void) G_GNUC_CONST;
+
+#define GGIT_TYPE_DIFF_FIND_FLAGS	(ggit_diff_find_flags_get_type())
+GType ggit_diff_find_flags_get_type	(void) G_GNUC_CONST;
+
+#define GGIT_TYPE_DIFF_FORMAT_EMAIL_FLAGS	(ggit_diff_format_email_flags_get_type())
+GType ggit_diff_format_email_flags_get_type	(void) G_GNUC_CONST;
+
 G_END_DECLS
 
 #endif /* __GGIT_ENUM_TYPES_H__ */
