@@ -34,6 +34,7 @@
 #include <libgit2-glib/ggit-branch.h>
 #include <libgit2-glib/ggit-blob-output-stream.h>
 #include <libgit2-glib/ggit-checkout-options.h>
+#include <libgit2-glib/ggit-note.h>
 
 G_BEGIN_DECLS
 
@@ -387,6 +388,36 @@ GgitIndex          *ggit_repository_cherry_pick_commit (GgitRepository
                                                         GgitMergeOptions         *merge_options,
                                                         GError                  **error);
 
+const gchar        *ggit_repository_get_default_notes_ref (GgitRepository           *repository,
+                                                           GError                  **error);
+
+GgitOId            *ggit_repository_create_note        (GgitRepository          *repository,
+                                                        GgitSignature           *author,
+                                                        GgitSignature           *committer,
+                                                        const gchar             *notes_ref,
+                                                        GgitOId                 *id,
+                                                        const gchar             *note,
+                                                        gboolean                 force,
+                                                        GError                 **error);
+
+gboolean            ggit_repository_remove_note        (GgitRepository          *repository,
+                                                        const gchar             *notes_ref,
+                                                        GgitSignature           *author,
+                                                        GgitSignature           *committer,
+                                                        GgitOId                 *id,
+                                                        GError                 **error);
+
+GgitNote           *ggit_repository_read_note          (GgitRepository          *repository,
+                                                        const gchar             *notes_ref,
+                                                        GgitOId                 *id,
+                                                        GError                 **error);
+
+gboolean            ggit_repository_note_foreach       (GgitRepository          *repository,
+                                                        const gchar             *notes_ref,
+                                                        GgitNoteCallback         callback,
+                                                        gpointer                 user_data,
+                                                        GError                 **error);
+
 G_END_DECLS
 
 #endif /* __GGIT_REPOSITORY_H__ */
