@@ -242,6 +242,13 @@ typedef struct _GgitMergeOptions GgitMergeOptions;
  */
 typedef struct _GgitNative GgitNative;
 
+/**
+ * GgitNote:
+ *
+ * Represents a note object.
+ */
+typedef struct _GgitNote GgitNote;
+
 /**
  * GgitObject:
  *
@@ -1184,6 +1191,21 @@ typedef gint (* GgitDiffSimilarityMetricSimilarityCallback) (gint     *score,
                                                              gpointer  signature_b,
                                                              gpointer  user_data);
 
+/**
+ * GgitNoteCallback:
+ * @blob_id: id of the blob containing the message.
+ * @annotated_object_id: id of the git object being annotated.
+ * @user_data: (closure): user-suplied data.
+ *
+ * When iterating over all the notes, callback that will be
+ * issued per note. See ggit_repository_note_foreach().
+ *
+ * Returns: 0 to go continue or a #GgitError in case there was an error.
+ */
+typedef gint (* GgitNoteCallback) (GgitOId *blob_id,
+                                   GgitOId *annotated_object_id,
+                                   gpointer user_data);
+
 /**
  * GgitReferencesNameCallback:
  * @name: the name of the reference
@@ -1232,7 +1254,7 @@ typedef gint (* GgitRemoteListCallback) (const gchar *name,
 typedef gint (* GgitStashCallback) (gsize        index,
                                     const gchar *message,
                                     GgitOId     *stash_oid,
-                                    gpointer    *user_data);
+                                    gpointer     user_data);
 
 /**
  * GgitStatusCallback:
@@ -1277,7 +1299,7 @@ typedef gint (* GgitSubmoduleCallback) (GgitSubmodule *submodule,
  */
 typedef gint (* GgitTagCallback) (const gchar *name,
                                   GgitOId     *tag_oid,
-                                  gpointer    *user_data);
+                                  gpointer     user_data);
 
 /**
  * GgitTransferProgressCallback:
